pub struct LazyAlgorithmicConfig {
pub indexing_approach: String,
pub query_approach: String,
pub cost_optimization: String,
}Expand description
Configuration for lazy algorithmic approach with selective LLM enhancement.
This strategy primarily uses algorithmic methods and only invokes LLMs when necessary to improve quality or handle complex cases.
Fields
indexing_approach: StringIndexing strategy (e.g., “algorithmic_first”, “llm_assisted”, “hybrid”)
query_approach: StringQuery processing strategy (e.g., “algorithmic_only”, “selective_llm”, “adaptive”)
cost_optimization: StringCost optimization strategy (e.g., “aggressive”, “balanced”, “quality_first”)