pub struct PureAlgorithmicConfig {
pub enabled: bool,
pub pattern_extraction: PatternExtractionConfig,
pub keyword_extraction: PureKeywordExtractionConfig,
pub relationship_discovery: RelationshipDiscoveryConfig,
pub search_ranking: SearchRankingConfig,
}Expand description
Configuration for pure algorithmic GraphRAG approach without LLM dependencies.
This configuration enables cost-effective graph construction and analysis using only algorithmic methods for pattern extraction, keyword analysis, and relationship discovery.
Fields
enabled: boolWhether the pure algorithmic approach is enabled
pattern_extraction: PatternExtractionConfigConfiguration for extracting linguistic patterns from text
keyword_extraction: PureKeywordExtractionConfigConfiguration for keyword extraction using statistical methods
relationship_discovery: RelationshipDiscoveryConfigConfiguration for discovering relationships between entities
search_ranking: SearchRankingConfigConfiguration for search result ranking algorithms