pub struct EntityMention {
pub chunk_id: ChunkId,
pub start_offset: usize,
pub end_offset: usize,
pub confidence: f32,
}Expand description
A mention of an entity in text
Fields
chunk_id: ChunkIdID of the chunk containing this mention
start_offset: usizeStarting character offset of the mention in the chunk
end_offset: usizeEnding character offset of the mention in the chunk
confidence: f32Confidence score for this specific mention (0.0-1.0)